"""
Input deck for 30p30n steady state simulation

Produced by Zenotech LTD 2023
"""

# import python modules required to interpret control dictionary
import zutil
import math

# define a function to rotate the output forces by the angle of attack
def my_transform(x,y,z):
    v = [x,y,z]
    v =  zutil.rotate_vector(v,0.0,alpha)
    return {'v1' : v[0], 'v2' : v[1], 'v3' : v[2]}

# create variables to assign main experimental parameters
reynolds = 1.71e6
mach = 0.17
T = 295.56
p = 101325
R = 287.6
gamma = 1.4
reference_length = 0.457
alpha = 5.5

# calculate implicit values
rho = p / (R * T)
U = math.sqrt(gamma * R * T) * mach

# assign each mesh zone to a boundary
wall = [6]
symmetry = [4,5]
farfield =[7]

parameters = { 
    'units' : 'SI',

    'reference' : 'IC_1',
    
    # scale the mesh
    'scale' : [0.0254,0.0254,0.0254/0.127],
    
    'restart' : False,
    
    'partitioner' : 'metis',
    
    'time marching' : { 
        'unsteady' : {
            'total time' : 1.0,
            'time step' : 1.0,
            'order' : 'second',
        },
        'scheme' : {
            'name' : 'implicit euler',
            'stage': 1,
        },
        'cfl': 50.0,
        "cfl ramp factor": {"initial": 1.0, "growth": 1.1},
        'cycles' : 1000,
    },
    
    'equations' : 'RANS',
    
    'RANS' : {
        'order' : 'euler_second',
        'turbulence' : {
            'model' : 'sst',
            'limit mut' : False,
            'production' : 2, 
        },
        'precondition' : True,
        'inviscid flux scheme': 'Roe',
    },
    'material' : 'air',
    'air' : {
        'gamma' : gamma,
        'gas constant' : R,
        'Sutherlands const': 110.4,
        'Prandtl No' : 0.72,
        'Turbulent Prandtl No' : 0.9,
    },
    'IC_1' : {
        'temperature': T,
        'pressure': p,
        'V': {
            # rotate the freestream vector by the angle of attack
            'vector' : zutil.vector_from_angle(0.0,alpha,U),
        },
        'Reynolds No' : reynolds,
        'Reference Length' : reference_length, 
        'turbulence intensity': 0.01,
        'eddy viscosity ratio': 0.10,
    },
    'BC_1' : {
        'zone' : symmetry,
        'type' : 'symmetry',
    },
    'BC_2' : {
        'zone' : wall,
        'type' : 'wall',
        'kind' : 'noslip',
    },
    'BC_3' : {
        'zone' : farfield,
        'type' : 'farfield',
        'condition' : 'IC_1',
        'kind' : 'riemann',
    },
    'write output' : {
        'format' : 'vtk',
        'surface variables': ['p', 'cp', 'V'],
        'volume variables': ['V','p','T','rho','var_6','eddy','turbulencekineticenergy','turbulenceeddyfrequency', 'walldist'],
        'frequency' : 500,
    },         
    'report' : {
        'frequency' : 50,
        
        'forces' : {
            'FR_1' : {
                'name' : 'wall',
                'zone' :  wall,
                # rotate output force vector by angle of attack
                'transform' : my_transform,
                'reference area' :0.4572,
            },
        },
    },                   
}

############################
#
# Variable list
#
# var_1 to var_n
# p,pressure
# T, temperature
#
############################

